// This will trigger the toggle when the chosen key is pressed. Based on SwiftTabs by Gom Kim.
window.addEventListener("keypress", hidetb, false);

function hidetb(event)
{
	pref_keytotoggle = getPrefValue("pref_keytotoggle","int");
	pref_ctrl = getPrefValue("pref_ctrl","bool");
	pref_alt = getPrefValue("pref_alt","bool");	  
	pref_shift = getPrefValue("pref_shift","bool");
	pref_comm = getPrefValue("pref_comm","bool");	
	pref_override = getPrefValue("pref_override","bool");
	
	// If no prefs were set yet
	if (!getPrefValue("pref_hideDelay","int"))
	{
		pref_keytotoggle = KeyEvent.DOM_VK_F11;
		pref_ctrl = true;
		
		// Set the default prefs
		var prefService = Components.classes['@mozilla.org/preferences-service;1'].getService(Components.interfaces.nsIPrefService).getBranch('hidetb.');
		prefService.setIntPref("pref_hideDelay",	1000);
		prefService.setIntPref("pref_keytotoggle",  pref_keytotoggle);
		prefService.setBoolPref("pref_ctrl",		pref_ctrl);
	}

	keyCode = event.keyCode;
	
	keyApplied = false;
	
	if (!pref_override)
	{
		if (keyCode < KeyEvent.DOM_VK_F1 || keyCode > KeyEvent.DOM_VK_F12)
		{
			var elt = document.commandDispatcher.focusedElement;
			if (elt)
			{
				var ln = elt.localName.toLowerCase();
				if (ln == "input" || ln == "textarea" ||	ln == "select"	|| ln == "button" || ln == "isindex")
				return;
			}
			
			var win =	document.commandDispatcher.focusedWindow;
			if (win && win.document.designMode	== "on")
				return;
		}
	}
	
	if (pref_keytotoggle > 1000)
	{
		keyCode = event.charCode + 1000;
	}
	else
	{
		keyCode = event.keyCode;
	}

	if (keyCode == pref_keytotoggle && event.metaKey == pref_comm && event.ctrlKey == pref_ctrl && event.altKey == pref_alt && event.shiftKey == pref_shift)
	{
		toggleBar();						//calling for toggle.
		keyApplied = true;
	}

	if (pref_override && keyApplied)
	{	
		event.preventDefault();
		event.preventBubble();
		event.preventCapture();
		event.stopPropagation();
	}
}

function getPrefValue(prefName,prefType)
{
	var prefService = Components.classes['@mozilla.org/preferences-service;1'].getService(Components.interfaces.nsIPrefService).getBranch('hidetb.');
	if (prefService.prefHasUserValue(prefName))
	{
		switch (prefType)
		{
			case	'int': return prefService.getIntPref(prefName);
			case	'bool': return	prefService.getBoolPref(prefName);
		}
	}
	else
	{
		switch (prefType)
		{
			case	'int': prefService.setIntPref(prefName,0);
			case	'bool': prefService.setBoolPref(prefName,false);
		}
		return false;
	}
}

// ==================================
//  function initOptionsWindow()
// ==================================
// Loads the prefs to the options dialog
function initOptionsWindow()
{
	// Auto hide prefs
	document.getElementById("autoHide").checked	 = getPrefValue("pref_autoHide","bool");
	document.getElementById("hideDelay").value	 = getPrefValue("pref_hideDelay","int");
	ChangeAutoHideStatus();
	
	// Toggle key prefs
	document.getElementById("keytotoggle").value = getPrefValue("pref_keytotoggle","int");
	document.getElementById("ctrl").checked		 = getPrefValue("pref_ctrl","bool");
	document.getElementById("alt").checked		 = getPrefValue("pref_alt","bool");
	document.getElementById("comm").checked		 = getPrefValue("pref_comm","bool");
	document.getElementById("shift").checked	 = getPrefValue("pref_shift","bool");
	document.getElementById("override").checked	 = getPrefValue("pref_override","bool");
}

// ==================================
//  function setPrefValue()
// ==================================
// Sets the prefs changed in the options dialog
function setPrefValue()
{
	var prefService = Components.classes['@mozilla.org/preferences-service;1'].getService(Components.interfaces.nsIPrefService).getBranch('hidetb.');
	
	// Auto hide prefs
	prefService.setBoolPref("pref_autoHide", document.getElementById("autoHide").checked);
	prefService.setIntPref("pref_hideDelay", document.getElementById("hideDelay").value);
	
	// Toggle key prefs
	prefService.setIntPref("pref_keytotoggle",  document.getElementById("keytotoggle").value);
	prefService.setBoolPref("pref_ctrl",		document.getElementById("ctrl").checked);
	prefService.setBoolPref("pref_alt",			document.getElementById("alt").checked);
	prefService.setBoolPref("pref_shift",		document.getElementById("shift").checked);
	prefService.setBoolPref("pref_comm",		document.getElementById("comm").checked);
	prefService.setBoolPref("pref_override",	document.getElementById("override").checked);
}

// ==================================
//  function ChangeAutoHideStatus()
// ==================================
// Disable or Enable the Auto Hide options.
function ChangeAutoHideStatus()
{
	// If auto hide is enabled
	if (document.getElementById("autoHide").checked)
	{
		document.getElementById("hideDelay").disabled = false;
	}
	
	// If auto hide is disabled
	else
	{
		document.getElementById("hideDelay").disabled = true;
	}
}

